@@ -8,14 +8,18 @@ bash create_gif.sh debugging
 # data model
 python immutable.py
 python mutable.py
-python copies.py
+python copy_mutable.py
 python copy_method.py
+python copy_immutable.py
+python copy_mix.py
 python name_rebinding.py
 
 # call stack
 python add_one.py
 python factorial.py
 bash create_gif.sh factorial
+python binary.py
+bash create_gif.sh binary
 python power_set.py
 bash create_gif.sh power_set
 
@@ -26,13 +30,12 @@ python hash_set.py
 
 # configuration
 python not_node_types.py
-python highlight.py
-
-# extensions
-python extension_numpy.py
-python extension_pandas.py
 
 # introspection
 python avltree.py
 python bin_search.py
 python introspect_depth.py
+
+# extensions
+python extension_numpy.py
+python extension_pandas.py
