@@ -29,7 +29,7 @@ type_to_node = { }
 
 type_to_color = { }
 
-type_to_vertical_orientation = { }
+type_to_vertical = { }
 
 type_to_slicer = { }
 
